Quick start:

    git clone git@github.com:clawpack/clawpack.git
    cd clawpack
    pip install -e .
    cd clawpack/pyclaw/examples/euler_2d
    python shockbubble.py iplot=1


# PyClaw

Pyclaw is a Python-based solver for hyperbolic PDEs that includes the algorithms
of Clawpack and SharpClaw.  
It has been designed with easy extensibility, performance, and exploration in mind.
PyClaw also includes a scalable parallel implementation of Clawpack using PETSc.

You can get the latest development version of PyClaw from
http://github.com/clawpack/.
